==> sportsdataverse-0.0.3-py3-none-any.whl: sportsdataverse/config.py <==
SGITHUB = 'https://raw.githubusercontent.com/saiemgilani/'
NFLVERSEGITHUB='https://raw.githubusercontent.com/nflverse/'
CFB_BASE_URL = SGITHUB+'cfbfastR-data/master/pbp/parquet/play_by_play_{season}.parquet'
CFB_ROSTER_URL = SGITHUB+'cfbfastR-data/master/rosters/parquet/rosters_{season}.parquet'
CFB_TEAM_LOGO_URL  = SGITHUB+'cfbfastR-data/master/teams/teams_colors_logos.parquet'
CFB_TEAM_SCHEDULE_URL = SGITHUB+'cfbfastR-data/master/schedules/parquet/schedules_{season}.parquet'
CFB_TEAM_INFO_URL = SGITHUB+'cfbfastR-data/master/team_info/parquet/team_info_{season}.parquet'

NFL_BASE_URL = NFLVERSEGITHUB+'nflfastR-data/master/data/play_by_play_{season}.parquet'
NFL_PLAYER_STATS_URL = NFLVERSEGITHUB+'nflfastR-data/master/data/player_stats.parquet'
NFL_ROSTER_URL = NFLVERSEGITHUB+'nflfastR-roster/master/data/nflfastR-roster.csv.gz'
NFL_TEAM_LOGO_URL  = NFLVERSEGITHUB+'nflfastR-data/master/teams_colors_logos.csv'
NFL_TEAM_SCHEDULE_URL = SGITHUB+'nflfastR-data/master/schedules/sched_{season}.parquet'

NHL_BASE_URL = NFLVERSEGITHUB+'nflfastR-data/master/data/play_by_play_{season}.parquet'
NHL_PLAYER_STATS_URL = NFLVERSEGITHUB+'nflfastR-data/master/data/player_stats.parquet'
NHL_ROSTER_URL = NFLVERSEGITHUB+'nflfastR-roster/master/data/nflfastR-roster.csv.gz'
NHL_TEAM_LOGO_URL  = NFLVERSEGITHUB+'nflfastR-data/master/teams_colors_logos.csv'
NHL_TEAM_SCHEDULE_URL = SGITHUB+'nflfastR-data/master/schedules/sched_{season}.parquet'


MBB_BASE_URL = SGITHUB+'hoopR-data/master/mbb/pbp/parquet/play_by_play_{season}.parquet'
MBB_TEAM_BOX_URL = SGITHUB+'hoopR-data/master/mbb/team_box/parquet/team_box_{season}.parquet'
MBB_PLAYER_BOX_URL = SGITHUB+'hoopR-data/master/mbb/player_box/parquet/player_box_{season}.parquet'
MBB_TEAM_LOGO_URL  = SGITHUB+'hoopR-data/master/mbb/teams_colors_logos.csv'
MBB_TEAM_SCHEDULE_URL = SGITHUB+'hoopR-data/master/mbb/schedules/parquet/mbb_schedule_{season}.parquet'
NBA_BASE_URL = SGITHUB+'hoopR-data/master/nba/pbp/parquet/play_by_play_{season}.parquet'
NBA_TEAM_BOX_URL = SGITHUB+'hoopR-data/master/nba/team_box/parquet/team_box_{season}.parquet'
NBA_PLAYER_BOX_URL  = SGITHUB+'hoopR-data/master/nba/player_box/parquet/player_box_{season}.parquet'
NBA_TEAM_SCHEDULE_URL = SGITHUB+'hoopR-data/master/nba/schedules/parquet/nba_schedule_{season}.parquet'
WBB_BASE_URL = SGITHUB+'wehoop-data/master/wbb/pbp/parquet/play_by_play_{season}.parquet'
WBB_TEAM_BOX_URL = SGITHUB+'wehoop-data/master/wbb/team_box/parquet/team_box_{season}.parquet'
WBB_PLAYER_BOX_URL = SGITHUB+'wehoop-data/master/wbb/player_box/parquet/player_box_{season}.parquet'
WBB_TEAM_LOGO_URL  = SGITHUB+'wehoop-data/master/wbb/teams_colors_logos.csv'
WBB_TEAM_SCHEDULE_URL = SGITHUB+'wehoop-data/master/wbb/schedules/parquet/wbb_schedule_{season}.parquet'
WNBA_BASE_URL = SGITHUB+'wehoop-data/master/wnba/pbp/parquet/play_by_play_{season}.parquet'
WNBA_TEAM_BOX_URL = SGITHUB+'wehoop-data/master/wnba/team_box/parquet/team_box_{season}.parquet'
WNBA_PLAYER_BOX_URL  = SGITHUB+'wehoop-data/master/wnba/player_box/parquet/player_box_{season}.parquet'
WNBA_TEAM_SCHEDULE_URL = SGITHUB+'wehoop-data/master/wnba/schedules/parquet/wnba_schedule_{season}.parquet'

==> sportsdataverse-0.0.16-py3-none-any.whl: sportsdataverse/config.py <==
SGITHUB = 'https://raw.githubusercontent.com/sportsdataverse/'
NFLVERSEGITHUB='https://raw.githubusercontent.com/nflverse/'

CFB_BASE_URL = SGITHUB+'cfbfastR-data/master/pbp/parquet/play_by_play_{season}.parquet'
CFB_ROSTER_URL = SGITHUB+'cfbfastR-data/master/rosters/parquet/rosters_{season}.parquet'
CFB_TEAM_LOGO_URL  = SGITHUB+'cfbfastR-data/master/teams/teams_colors_logos.parquet'
CFB_TEAM_SCHEDULE_URL = SGITHUB+'cfbfastR-data/master/schedules/parquet/schedules_{season}.parquet'
CFB_TEAM_INFO_URL = SGITHUB+'cfbfastR-data/master/team_info/parquet/team_info_{season}.parquet'

NFL_BASE_URL = NFLVERSEGITHUB+'nflfastR-data/master/data/play_by_play_{season}.parquet'
NFL_PLAYER_STATS_URL = NFLVERSEGITHUB+'nflfastR-data/master/data/player_stats.parquet'
NFL_ROSTER_URL = NFLVERSEGITHUB+'nflfastR-roster/master/data/nflfastR-roster.csv.gz'
NFL_TEAM_LOGO_URL  = NFLVERSEGITHUB+'nflfastR-data/master/teams_colors_logos.csv'
NFL_TEAM_SCHEDULE_URL = SGITHUB+'nflfastR-data/master/schedules/sched_{season}.parquet'

NHL_BASE_URL = SGITHUB+'fastRhockey-data/main/nhl/pbp/parquet/play_by_play_{season}.parquet'
NHL_PLAYER_BOX_URL = SGITHUB+'fastRhockey-data/main/nhl/player_box/parquet/player_box_{season}.parquet'
NHL_TEAM_BOX_URL = SGITHUB+'fastRhockey-data/main/nhl/team_box/parquet/team_box_{season}.parquet'
NHL_TEAM_SCHEDULE_URL = SGITHUB+'fastRhockey-data/main/nhl/schedules/parquet/nhl_schedule_{season}.parquet'
NHL_TEAM_LOGO_URL  = SGITHUB+'fastRhockey-data/main/nhl/nhl_teams_colors_logos.csv'

PHF_BASE_URL = SGITHUB+'fastRhockey-data/main/phf/pbp/parquet/play_by_play_{season}.parquet'
PHF_PLAYER_BOX_URL = SGITHUB+'fastRhockey-data/main/phf/player_box/parquet/player_box_{season}.parquet'
PHF_TEAM_BOX_URL = SGITHUB+'fastRhockey-data/main/phf/team_box/parquet/team_box_{season}.parquet'
PHF_TEAM_SCHEDULE_URL = SGITHUB+'fastRhockey-data/main/phf/schedules/parquet/phf_schedule_{season}.parquet'

MBB_BASE_URL = SGITHUB+'hoopR-data/master/mbb/pbp/parquet/play_by_play_{season}.parquet'
MBB_TEAM_BOX_URL = SGITHUB+'hoopR-data/master/mbb/team_box/parquet/team_box_{season}.parquet'
MBB_PLAYER_BOX_URL = SGITHUB+'hoopR-data/master/mbb/player_box/parquet/player_box_{season}.parquet'
MBB_TEAM_LOGO_URL  = SGITHUB+'hoopR-data/master/mbb/teams_colors_logos.csv'
MBB_TEAM_SCHEDULE_URL = SGITHUB+'hoopR-data/master/mbb/schedules/parquet/mbb_schedule_{season}.parquet'

NBA_BASE_URL = SGITHUB+'hoopR-data/master/nba/pbp/parquet/play_by_play_{season}.parquet'
NBA_TEAM_BOX_URL = SGITHUB+'hoopR-data/master/nba/team_box/parquet/team_box_{season}.parquet'
NBA_PLAYER_BOX_URL  = SGITHUB+'hoopR-data/master/nba/player_box/parquet/player_box_{season}.parquet'
NBA_TEAM_SCHEDULE_URL = SGITHUB+'hoopR-data/master/nba/schedules/parquet/nba_schedule_{season}.parquet'

WBB_BASE_URL = SGITHUB+'wehoop-data/master/wbb/pbp/parquet/play_by_play_{season}.parquet'
WBB_TEAM_BOX_URL = SGITHUB+'wehoop-data/master/wbb/team_box/parquet/team_box_{season}.parquet'
WBB_PLAYER_BOX_URL = SGITHUB+'wehoop-data/master/wbb/player_box/parquet/player_box_{season}.parquet'
WBB_TEAM_LOGO_URL  = SGITHUB+'wehoop-data/master/wbb/teams_colors_logos.csv'
WBB_TEAM_SCHEDULE_URL = SGITHUB+'wehoop-data/master/wbb/schedules/parquet/wbb_schedule_{season}.parquet'

WNBA_BASE_URL = SGITHUB+'wehoop-data/master/wnba/pbp/parquet/play_by_play_{season}.parquet'
WNBA_TEAM_BOX_URL = SGITHUB+'wehoop-data/master/wnba/team_box/parquet/team_box_{season}.parquet'
WNBA_PLAYER_BOX_URL  = SGITHUB+'wehoop-data/master/wnba/player_box/parquet/player_box_{season}.parquet'
WNBA_TEAM_SCHEDULE_URL = SGITHUB+'wehoop-data/master/wnba/schedules/parquet/wnba_schedule_{season}.parquet'
